==> ReleaseV1.1.0.tar.gz: winginterfacelibrary/src/Interface/IPatientService.cs <==
﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Patient;
using WingInterfaceLibrary.Request.Patient;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 客户端调用病人信息接口
    /// </summary>
    /// <value>病人信息接口</value>
    /// <example>客户端API</example>
    [System.ComponentModel.Description("WingRemedicalModule")]
    public interface IPatientService
    {
        /// <summary>
        /// 创建病人
        /// </summary>
        /// <param name="request">创建病人信息请求实体</param>
        /// <returns>是否创建成功</returns>
        /// <value>true</value>
        /// <para>CreatePatientErrorEnum</para>
        /// <errorCodes>PatientDataIsEmpty,UserNotExistError,RootOrgNotExistError,PhoneAndNameExistError,NameEmptyError,NameLengthError,PhoneEmptyError,PhoneLengthError,SexError</errorCodes>
        Task<bool> CreatePatientAsync(CreatePatientRequest request);

        /// <summary>
        /// 未登记关联创建病人
        /// </summary>
        /// <param name="request">未登记关联创建病人人信息请求实体</param>
        /// <returns>是否创建成功</returns>
        /// <value>true</value>
        /// <errorCodes>UnregisteredPatientCodeIsEmpty,PatientNameIsEmpty,UnregisteredPatientNotExisted,PatientWasRegistered</errorCodes>
        Task<bool> CreatePatientByUnregisteredAsync(CreatePatientByUnregisteredRequest request);

        /// <summary>
        /// 修改病人信息
        /// </summary>
        /// <param name="request">修改病人请求实体</param>
        /// <returns>是否更新成功</returns>
        /// <value>true</value>
        /// <para>UpdatePatientErrorEnum</para>
        /// <errorCodes>PatientDataIsEmpty,UserNotExistError,RootOrgNotExistError,PatientNotExistError,NameEmptyError,NameLengthError,PhoneEmptyError,PhoneLengthError,SexError</errorCodes>
        Task<bool> UpdatePatientAsync(UpdatePatientRequest request);

        Task<bool> CreatePatientsAsync(CreatePatientsRequest request);

        /// <summary>
        /// 分页查询病人列表
        /// </summary>
        /// <param name="request">查询病人请求实体</param>
        /// <returns>返回病人列表</returns>
        /// <para>SearchPatientErrorEnum</para>
        Task<PageResult<ClientPatientInfoBaseDTO>> FindPatientsAsync(FindPatientsPageRequest  request);

        /// <summary>
        /// 查询病人详细信息
        /// </summary>
        /// <param name="request">获取病人信息的请求实体</param>
        /// <returns>病人详细信息实体</returns>
        /// <errorCodes>PatientCodeIsEmpty</errorCodes>
        Task<ClientPatientInfoDTO> FindPatientByCodeAsync(FindPatientByCodeRequest request);

        /// <summary>
        /// 获取有效相同病人名称的列表
        /// </summary>
        /// <param name="request">获取相同病人姓名的请求实体</param>
        /// <returns>返回相同名称病人集合</returns>
        /// <errorCodes>NameEmptyError,RemedicalUserNotExisted</errorCodes>
        Task<List<ClientPatientInfoBaseDTO>> FindValidPatientsByNameAsync(FindValidPatientsByNameRequest request);

        /// <summary>
        /// 设置成有效已登记病人接口
        /// </summary>
        /// <returns></returns>
        /// <errorCodes>PatientCodeIsEmpty,UserNotExistError,PatientNotExistError,PatientInfoIsNotValid</errorCodes>
        Task<bool> SetValidPatientAsync(SetValidPatientRequest request);
        
        /// <summary>
        /// 删除病人
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> RemovePatientsAsync(RemovePatientsRequest request);
    }
}

==> ReleaseV1.1.3.tar.gz: winginterfacelibrary/src/Interface/IPatientService.cs <==
﻿using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Patient;
using WingInterfaceLibrary.Request.Patient;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 客户端调用病人信息接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>病人信息接口</docSecondDirectory>
    public interface IPatientService
    {
        /// <summary>
        /// 创建病人
        /// </summary>
        /// <param name="request">创建病人信息请求实体</param>
        /// <returns>是否创建成功</returns>
        /// <value>true</value>
        /// <errorCodes>PatientDataIsEmpty,UserNotExistError,RootOrgNotExistError,PhoneAndNameExistError,NameEmptyError,NameLengthError,PhoneEmptyError,PhoneLengthError,SexError</errorCodes>
        Task<bool> CreatePatientAsync(CreatePatientRequest request);

        /// <summary>
        /// 未登记关联创建病人
        /// </summary>
        /// <param name="request">未登记关联创建病人人信息请求实体</param>
        /// <returns>是否创建成功</returns>
        /// <value>true</value>
        /// <errorCodes>UnregisteredPatientCodeIsEmpty,PatientNameIsEmpty,UnregisteredPatientNotExisted,PatientWasRegistered</errorCodes>
        Task<bool> CreatePatientByUnregisteredAsync(CreatePatientByUnregisteredRequest request);

        /// <summary>
        /// 修改病人信息
        /// </summary>
        /// <param name="request">修改病人请求实体</param>
        /// <returns>是否更新成功</returns>
        /// <value>true</value>
        /// <errorCodes>PatientDataIsEmpty,UserNotExistError,RootOrgNotExistError,PatientNotExistError,NameEmptyError,NameLengthError,PhoneEmptyError,PhoneLengthError,SexError,PhoneAndNameExistError</errorCodes>
        Task<bool> UpdatePatientAsync(UpdatePatientRequest request);

        Task<bool> CreatePatientsAsync(CreatePatientsRequest request);

        /// <summary>
        /// 分页查询病人列表
        /// </summary>
        /// <param name="request">查询病人请求实体</param>
        /// <returns>返回病人列表</returns>
        Task<PageResult<ClientPatientInfoBaseDTO>> FindPatientsAsync(FindPatientsPageRequest  request);

        /// <summary>
        /// 查询病人详细信息
        /// </summary>
        /// <param name="request">获取病人信息的请求实体</param>
        /// <returns>病人详细信息实体</returns>
        /// <errorCodes>PatientCodeIsEmpty</errorCodes>
        Task<ClientPatientInfoDTO> FindPatientByCodeAsync(FindPatientByCodeRequest request);

        /// <summary>
        /// 获取有效相同病人名称的列表
        /// </summary>
        /// <param name="request">获取相同病人姓名的请求实体</param>
        /// <returns>返回相同名称病人集合</returns>
        /// <errorCodes>NameEmptyError,RemedicalUserNotExisted</errorCodes>
        Task<List<ClientPatientInfoBaseDTO>> FindValidPatientsByNameAsync(FindValidPatientsByNameRequest request);

        /// <summary>
        /// 设置成有效已登记病人接口
        /// </summary>
        /// <returns></returns>
        /// <errorCodes>PatientCodeIsEmpty,UserNotExistError,PatientNotExistError,PatientInfoIsNotValid</errorCodes>
        Task<bool> SetValidPatientAsync(SetValidPatientRequest request);
        
        /// <summary>
        /// 删除病人
        /// </summary>
        /// <returns>是否成功</returns>
        Task<bool> RemovePatientsAsync(RemovePatientsRequest request);
    }
}
